Index: /issm/trunk/src/c/Makefile.am
===================================================================
--- /issm/trunk/src/c/Makefile.am	(revision 4066)
+++ /issm/trunk/src/c/Makefile.am	(revision 4067)
@@ -410,6 +410,6 @@
 					./modules/ScaleInputx/ScaleInputx.h\
 					./modules/ScaleInputx/ScaleInputx.cpp\
-					./modules/AXPYInputx/AXPYInputx.h\
-					./modules/AXPYInputx/AXPYInputx.cpp\
+					./modules/InputAXPYx/InputAXPYx.h\
+					./modules/InputAXPYx/InputAXPYx.cpp\
 					./modules/ControlConstrainInputx/ControlConstrainInputx.h\
 					./modules/ControlConstrainInputx/ControlConstrainInputx.cpp\
@@ -931,6 +931,6 @@
 					./modules/ScaleInputx/ScaleInputx.h\
 					./modules/ScaleInputx/ScaleInputx.cpp\
-					./modules/AXPYInputx/AXPYInputx.h\
-					./modules/AXPYInputx/AXPYInputx.cpp\
+					./modules/InputAXPYx/InputAXPYx.h\
+					./modules/InputAXPYx/InputAXPYx.cpp\
 					./modules/ControlConstrainInputx/ControlConstrainInputx.h\
 					./modules/ControlConstrainInputx/ControlConstrainInputx.cpp\
Index: /issm/trunk/src/c/modules/InputAXPYx/InputAXPYx.cpp
===================================================================
--- /issm/trunk/src/c/modules/InputAXPYx/InputAXPYx.cpp	(revision 4066)
+++ /issm/trunk/src/c/modules/InputAXPYx/InputAXPYx.cpp	(revision 4067)
@@ -1,7 +1,7 @@
-/*!\file AXPYInputx
+/*!\file InputAXPYx
  * \brief: Y=Y+aX operation on inputs.
  */
 
-#include "./AXPYInputx.h"
+#include "./InputAXPYx.h"
 #include "../../shared/shared.h"
 #include "../../include/include.h"
@@ -9,5 +9,5 @@
 #include "../../EnumDefinitions/EnumDefinitions.h"
 
-void AXPYInputx(DataSet* elements,DataSet* nodes,DataSet* vertices,DataSet* loads,DataSet* materials,Parameters* parameters,int YEnum, double scalar, int XEnum){
+void InputAXPYx(DataSet* elements,DataSet* nodes,DataSet* vertices,DataSet* loads,DataSet* materials,Parameters* parameters,int YEnum, double scalar, int XEnum){
 
 	/*intermediary:*/
@@ -20,5 +20,5 @@
 	for(i=0;i<elements->Size();i++){
 		Element* element=(Element*)elements->GetObjectByOffset(i);
-		element->AXPYInput(YEnum, scalar, XEnum);
+		element->InputAXPY(YEnum, scalar, XEnum);
 	}
 }
Index: /issm/trunk/src/c/modules/InputAXPYx/InputAXPYx.h
===================================================================
--- /issm/trunk/src/c/modules/InputAXPYx/InputAXPYx.h	(revision 4066)
+++ /issm/trunk/src/c/modules/InputAXPYx/InputAXPYx.h	(revision 4067)
@@ -1,3 +1,3 @@
-/*!\file:  AXPYInputx.h
+/*!\file:  InputAXPYx.h
  * \brief header file for field extrusion
  */ 
@@ -9,5 +9,5 @@
 
 /* local prototypes: */
-void AXPYInputx(DataSet* elements,DataSet* nodes,DataSet* vertices,DataSet* loads,DataSet* materials,Parameters* parameters,int YEnum, double scalar, int XEnum);
+void InputAXPYx(DataSet* elements,DataSet* nodes,DataSet* vertices,DataSet* loads,DataSet* materials,Parameters* parameters,int YEnum, double scalar, int XEnum);
 
 #endif  /* _AXPYINPUTX_H */
Index: /issm/trunk/src/c/objects/Elements/Beam.h
===================================================================
--- /issm/trunk/src/c/objects/Elements/Beam.h	(revision 4066)
+++ /issm/trunk/src/c/objects/Elements/Beam.h	(revision 4067)
@@ -96,5 +96,5 @@
 		void  InputDuplicate(int original_enum,int new_enum);
 		void  ScaleInput(int enum_type,double scale_factor);
-		void  AXPYInput(int YEnum, double scalar, int XEnum);
+		void  InputAXPY(int YEnum, double scalar, int XEnum);
 		void  ControlConstrainInput(int control_type,double cm_min, double cm_max);
 		void  InputConvergence(int* pconverged,double* eps, int* enums,int num_enums,int* criterionenums,double* criterionvalues,int num_criterionenums);
Index: /issm/trunk/src/c/objects/Elements/Element.h
===================================================================
--- /issm/trunk/src/c/objects/Elements/Element.h	(revision 4066)
+++ /issm/trunk/src/c/objects/Elements/Element.h	(revision 4067)
@@ -67,5 +67,5 @@
 		virtual void   ScaleInput(int enum_type,double scale_factor)=0;
 		virtual void   GetVectorFromInputs(Vec vector,int NameEnum)=0;
-		virtual void   AXPYInput(int YEnum, double scalar, int XEnum)=0;
+		virtual void   InputAXPY(int YEnum, double scalar, int XEnum)=0;
 		virtual void   ControlConstrainInput(int control_type,double cm_min, double cm_max)=0;
 		virtual void   InputConvergence(int* pconverged,double* eps, int* enums,int num_enums,int* criterionenums,double* criterionvalues,int num_criterionenums)=0;
Index: /issm/trunk/src/c/objects/Elements/Penta.h
===================================================================
--- /issm/trunk/src/c/objects/Elements/Penta.h	(revision 4066)
+++ /issm/trunk/src/c/objects/Elements/Penta.h	(revision 4067)
@@ -163,5 +163,5 @@
 		void  InputDuplicate(int original_enum,int new_enum);
 		void  ScaleInput(int enum_type,double scale_factor);
-		void  AXPYInput(int YEnum, double scalar, int XEnum);
+		void  InputAXPY(int YEnum, double scalar, int XEnum);
 		void  ControlConstrainInput(int control_type,double cm_min, double cm_max);
 		void  InputConvergence(int* pconverged,double* eps, int* enums,int num_enums,int* criterionenums,double* criterionvalues,int num_criterionenums);
Index: /issm/trunk/src/c/objects/Elements/Sing.h
===================================================================
--- /issm/trunk/src/c/objects/Elements/Sing.h	(revision 4066)
+++ /issm/trunk/src/c/objects/Elements/Sing.h	(revision 4067)
@@ -95,5 +95,5 @@
 		void  InputDuplicate(int original_enum,int new_enum);
 		void  ScaleInput(int enum_type,double scale_factor);
-		void  AXPYInput(int YEnum, double scalar, int XEnum);
+		void  InputAXPY(int YEnum, double scalar, int XEnum);
 		void  InputConvergence(int* pconverged,double* eps, int* enums,int num_enums,int* criterionenums,double* criterionvalues,int num_criterionenums);
 		void  ControlConstrainInput(int control_type,double cm_min, double cm_max);
Index: /issm/trunk/src/c/objects/Elements/Tria.h
===================================================================
--- /issm/trunk/src/c/objects/Elements/Tria.h	(revision 4066)
+++ /issm/trunk/src/c/objects/Elements/Tria.h	(revision 4067)
@@ -141,5 +141,5 @@
 		void  InputDuplicate(int original_enum,int new_enum);
 		void  ScaleInput(int enum_type,double scale_factor);
-		void  AXPYInput(int YEnum, double scalar, int XEnum);
+		void  InputAXPY(int YEnum, double scalar, int XEnum);
 		void  InputConvergence(int* pconverged,double* eps, int* enums,int num_enums,int* criterionenums,double* criterionvalues,int num_criterionenums);
 		void  ControlConstrainInput(int control_type,double cm_min, double cm_max);
Index: /issm/trunk/src/c/solutions/control_core.cpp
===================================================================
--- /issm/trunk/src/c/solutions/control_core.cpp	(revision 4066)
+++ /issm/trunk/src/c/solutions/control_core.cpp	(revision 4067)
@@ -89,5 +89,5 @@
 
 		_printf_("%s","      updating parameter using optimized search scalar...");
-		AXPYInputx(femmodel->elements,femmodel->nodes,femmodel->vertices,femmodel->loads,femmodel->materials,femmodel->parameters,control_type,search_scalar*optscal[n],ControlParameterEnum);
+		InputAXPYx(femmodel->elements,femmodel->nodes,femmodel->vertices,femmodel->loads,femmodel->materials,femmodel->parameters,control_type,search_scalar*optscal[n],ControlParameterEnum);
 
 		_printf_("%s","      constraining the new distribution...");    
Index: /issm/trunk/src/c/solutions/objectivefunctionC.cpp
===================================================================
--- /issm/trunk/src/c/solutions/objectivefunctionC.cpp	(revision 4066)
+++ /issm/trunk/src/c/solutions/objectivefunctionC.cpp	(revision 4067)
@@ -57,5 +57,5 @@
 	
 	/*Use search scalar to shoot parameter in the gradient direction: */
-	AXPYInputx(femmodel->elements,femmodel->nodes,femmodel->vertices,femmodel->loads,femmodel->materials,femmodel->parameters,control_type,search_scalar*optscal[n],ControlParameterEnum);
+	InputAXPYx(femmodel->elements,femmodel->nodes,femmodel->vertices,femmodel->loads,femmodel->materials,femmodel->parameters,control_type,search_scalar*optscal[n],ControlParameterEnum);
 
 	/*Constrain:*/

Index: /issm/trunk/src/c/objects/Elements/Beam.cpp
===================================================================
--- /issm/trunk/src/c/objects/Elements/Beam.cpp	(revision 4066)
+++ /issm/trunk/src/c/objects/Elements/Beam.cpp	(revision 4067)
@@ -1009,6 +1009,6 @@
 }
 /*}}}*/
-/*FUNCTION Beam::AXPYInput(int YEnum, double scalar, int XEnum);{{{1*/
-void  Beam::AXPYInput(int YEnum, double scalar, int XEnum){
+/*FUNCTION Beam::InputAXPY(int YEnum, double scalar, int XEnum);{{{1*/
+void  Beam::InputAXPY(int YEnum, double scalar, int XEnum){
 
 	Input* xinput=NULL;
Index: /issm/trunk/src/c/objects/Elements/Penta.cpp
===================================================================
--- /issm/trunk/src/c/objects/Elements/Penta.cpp	(revision 4066)
+++ /issm/trunk/src/c/objects/Elements/Penta.cpp	(revision 4067)
@@ -5262,6 +5262,6 @@
 }
 /*}}}*/
-/*FUNCTION Penta::AXPYInput(int YEnum, double scalar, int XEnum);{{{1*/
-void  Penta::AXPYInput(int YEnum, double scalar, int XEnum){
+/*FUNCTION Penta::InputAXPY(int YEnum, double scalar, int XEnum);{{{1*/
+void  Penta::InputAXPY(int YEnum, double scalar, int XEnum){
 
 	Input* xinput=NULL;
Index: /issm/trunk/src/c/objects/Elements/Sing.cpp
===================================================================
--- /issm/trunk/src/c/objects/Elements/Sing.cpp	(revision 4066)
+++ /issm/trunk/src/c/objects/Elements/Sing.cpp	(revision 4067)
@@ -708,6 +708,6 @@
 }
 /*}}}*/
-/*FUNCTION Sing::AXPYInput(int YEnum, double scalar, int XEnum);{{{1*/
-void  Sing::AXPYInput(int YEnum, double scalar, int XEnum){
+/*FUNCTION Sing::InputAXPY(int YEnum, double scalar, int XEnum);{{{1*/
+void  Sing::InputAXPY(int YEnum, double scalar, int XEnum){
 
 	Input* xinput=NULL;
Index: /issm/trunk/src/c/objects/Elements/Tria.cpp
===================================================================
--- /issm/trunk/src/c/objects/Elements/Tria.cpp	(revision 4066)
+++ /issm/trunk/src/c/objects/Elements/Tria.cpp	(revision 4067)
@@ -5441,6 +5441,6 @@
 }
 /*}}}*/
-/*FUNCTION Tria::AXPYInput(int YEnum, double scalar, int XEnum);{{{1*/
-void  Tria::AXPYInput(int YEnum, double scalar, int XEnum){
+/*FUNCTION Tria::InputAXPY(int YEnum, double scalar, int XEnum);{{{1*/
+void  Tria::InputAXPY(int YEnum, double scalar, int XEnum){
 
 	Input* xinput=NULL;